# WebrtcStream


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**active** | **bool** |  | [optional] 
**admin_port** | **int** |  | [readonly] 
**admin_secret** | **str** |  | [readonly] 
**admin_url** | **str** |  | [readonly] 
**api_domain** | **str** |  | [readonly] 
**api_port** | **int** |  | [readonly] 
**api_token** | **str** |  | [readonly] 
**api_url** | **str** |  | [readonly] 
**config_type** | [**JanusConfigType**](JanusConfigType.md) |  | [optional] 
**created_dt** | **datetime** |  | [readonly] 
**id** | **int** |  | [readonly] 
**info** | **dict(str, object)** |  | [readonly] 
**is_admin** | **bool** |  | [readonly] 
**pi** | **int** |  | [readonly] 
**pt** | **int** |  | [readonly] 
**rtp_domain** | **str** |  | [readonly] 
**video_rtp_port** | **int** |  | [readonly] 
**data_rtp_port** | **int** |  | [readonly] 
**rtpmap** | **str** |  | [readonly] 
**stream_pin** | **str** |  | [readonly] 
**stream_secret** | **str** |  | [readonly] 
**updated_dt** | **datetime** |  | [readonly] 
**ws_port** | **int** |  | [readonly] 
**ws_url** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


